"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.AutocompleteInput = void 0;

var _react = _interopRequireDefault(require("react"));

var _reactNative = require("react-native");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const AutocompleteInput = props => {
  function renderResultList(data, listProps) {
    const {
      style,
      ...flatListProps
    } = listProps;
    return /*#__PURE__*/_react.default.createElement(_reactNative.FlatList, _extends({
      data: data,
      style: [styles.list, style]
    }, flatListProps));
  }

  function renderTextInput() {
    const {
      renderTextInput: renderFunction,
      style
    } = props;
    const textProps = {
      style: [styles.input, style] // ...props,

    };
    return renderFunction(textProps);
  }

  const {
    data,
    containerStyle,
    hideResults,
    inputContainerStyle,
    listContainerStyle,
    onShowResults,
    onStartShouldSetResponderCapture,
    flatListProps
  } = props;
  const showResults = data.length > 0; // Notify listener if the suggestion will be shown.

  onShowResults && onShowResults(showResults);
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [styles.container, containerStyle]
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [styles.inputContainer, inputContainerStyle]
  }, renderTextInput()), !hideResults && /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: listContainerStyle,
    onStartShouldSetResponderCapture: onStartShouldSetResponderCapture
  }, showResults && renderResultList(data, flatListProps)));
};

exports.AutocompleteInput = AutocompleteInput;

const defaultKeyExtractor = (_, index) => "key-".concat(index);

const defaultRenderItem = ({
  item
}) => /*#__PURE__*/_react.default.createElement(_reactNative.Text, null, item);

AutocompleteInput.defaultProps = {
  data: [],
  keyboardShouldPersistTaps: "always",
  onStartShouldSetResponderCapture: () => false,
  renderTextInput: props => /*#__PURE__*/_react.default.createElement(_reactNative.TextInput, props),
  flatListProps: {
    renderItem: defaultRenderItem,
    keyExtractor: defaultKeyExtractor
  }
};
const border = {
  borderColor: "#b9b9b9",
  borderRadius: 1,
  borderWidth: 1
};
const androidStyles = {
  container: {
    flex: 1
  },
  inputContainer: { ...border,
    marginBottom: 0
  },
  list: { ...border,
    backgroundColor: "white",
    borderTopWidth: 0,
    margin: 10,
    marginTop: 0
  }
};
const iosStyles = {
  container: {
    zIndex: 1
  },
  inputContainer: { ...border
  },
  input: {
    backgroundColor: "white",
    height: 40,
    paddingLeft: 3
  },
  list: { ...border,
    backgroundColor: "white",
    borderTopWidth: 0,
    left: 0,
    position: "absolute",
    right: 0
  }
};

const styles = _reactNative.StyleSheet.create({
  input: {
    backgroundColor: "white",
    height: 40,
    paddingLeft: 3
  },
  ..._reactNative.Platform.select({
    android: androidStyles,
    ios: iosStyles,
    default: iosStyles
  })
});

var _default = AutocompleteInput;
exports.default = _default;
//# sourceMappingURL=AutocompleteInput.js.map