import * as React from "react";
import styled from "styled-components";
import useScrollbarSize from "react-scrollbar-size";
import Appbar from "react-native-simple-elements/components/Appbar";
import AuthorizedUserMenu from "../AuthorizedUserMenu";
import AccountIcon from "@mdi/svg/svg/account.svg";

const HeaderContainer = styled.div({
    zIndex: 3,
});

type Props = {
    title?: string,
    backButtonIcon?: React.ReactElement,
    onBackButtonClick?: () => void,
    loggedInUser?: Record<string, any>;
    isUserIconCircle?: boolean,
    onLoginClick?: () => void,
    children?: React.ReactNode;
};

const defaultProps = {
    isUserIconCircle: true,
};

const SimpleHeader = (props: Props) => {

    const {
        title,
        backButtonIcon,
        onBackButtonClick,
        children,
        loggedInUser,
        isUserIconCircle,
        onLoginClick,
    } = props;

    const { width: scrollbarSize } = useScrollbarSize();

    const _handleBackActionPress = () => {
        if (typeof onBackButtonClick === "function") {
            onBackButtonClick();
        }
    };

    const _handleLoginClick = () => {
        if (typeof onLoginClick === "function") {
            onLoginClick();
        }
    };

    return (
        <HeaderContainer
            style={{
                marginRight: scrollbarSize || 0,
            }}
        >
            <Appbar.Header>
                <Appbar.BackAction
                    icon={backButtonIcon}
                    onPress={_handleBackActionPress}
                />
                <Appbar.Content
                    title={title}
                />
                {children}
                {loggedInUser?.userId ?
                    <AuthorizedUserMenu
                        circle={isUserIconCircle}
                        loggedInUser={loggedInUser}
                    /> :
                    <Appbar.Action
                        icon={AccountIcon}
                        onPress={_handleLoginClick}
                    />
                }
            </Appbar.Header>
        </HeaderContainer>
    );
};

SimpleHeader.defaultProps = defaultProps;

export default SimpleHeader;
